==> qt-components-hildon_0.1.1.tar.gz: qt-components-hildon-0.1.1/src/components/actiongroup_p.h <==
/*
 * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 3, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef ACTIONGROUP_P_H
#define ACTIONGROUP_P_H

#include <QActionGroup>
#include <QDeclarativeParserStatus>
#include <qdeclarative.h>

class ActionGroupPrivate;

class ActionGroup : public QActionGroup, public QDeclarativeParserStatus
{
    Q_OBJECT

    Q_PRIVATE_PROPERTY(ActionGroup::d_func(), QDeclarativeListProperty<QObject> data READ data)

    Q_INTERFACES(QDeclarativeParserStatus)

    Q_CLASSINFO("DefaultProperty", "data")

public:
    explicit ActionGroup(QObject *parent = 0);
    ~ActionGroup();

private:
    ActionGroup(ActionGroupPrivate &dd, QObject *parent = 0);

    void classBegin();
    void componentComplete();

    QScopedPointer<ActionGroupPrivate> d_ptr;

    Q_DISABLE_COPY(ActionGroup)
    Q_DECLARE_PRIVATE(ActionGroup)
};

QML_DECLARE_TYPE(ActionGroup)

#endif // ACTIONGROUP_P_H

==> qt-components-hildon_0.12.1.tar.gz: qt-components-hildon-0.12.1/src/components/actiongroup_p.h <==
/*
 * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 3, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef ACTIONGROUP_P_H
#define ACTIONGROUP_P_H

#include <QActionGroup>
#include <QDeclarativeParserStatus>
#include <qdeclarative.h>

class ActionGroupPrivate;

class ActionGroup : public QActionGroup, public QDeclarativeParserStatus
{
    Q_OBJECT

    Q_PROPERTY(bool enabled READ isEnabled WRITE setEnabled NOTIFY enabledChanged)
    Q_PRIVATE_PROPERTY(ActionGroup::d_func(), QDeclarativeListProperty<QObject> data READ data)

    Q_INTERFACES(QDeclarativeParserStatus)

    Q_CLASSINFO("DefaultProperty", "data")

public:
    explicit ActionGroup(QObject *parent = 0);
    ~ActionGroup();

signals:
    void enabledChanged();

protected:
    ActionGroup(ActionGroupPrivate &dd, QObject *parent = 0);

    virtual void classBegin();
    virtual void componentComplete();

    virtual bool event(QEvent *event);

    QScopedPointer<ActionGroupPrivate> d_ptr;

    Q_DECLARE_PRIVATE(ActionGroup)

private:
    Q_DISABLE_COPY(ActionGroup)
};

QML_DECLARE_TYPE(ActionGroup)

#endif // ACTIONGROUP_P_H
